@@ -112,46 +112,8 @@ DrawBasedOnRectangleSize.prototype.setState = function(state) {
 DrawBasedOnRectangleSize.prototype.initUiOptions = function(resume, restoreFromSettings) {
     EAction.prototype.initUiOptions.call(this, resume, restoreFromSettings);
 
-    this.referencePointIndex = RSettings.getIntValue(this.settingsGroup + "/ReferencePoint", 4);
-    
     var optionsToolBar = EAction.getOptionsToolBar();
-    var refPointCombo = optionsToolBar.findChild("ReferencePoint");
-
-    if (isNull(refPointCombo)) {
-        return;
-    }
-
-    refPointCombo.blockSignals(true);
-    refPointCombo.clear();
-    if (isNull(this.shortcuts)) {
-        this.shortcuts = [];
-    }
-
-    for (var i=0; i<this.referencePoints.length; i++) {
-        var shortcut = "Ctrl+%1".arg(i+1);
-        var shortcutLabel = shortcut;
-        if (RS.getSystemId()==="osx") {
-            shortcutLabel = shortcutLabel.replace("Ctrl+", "\u2318");
-        }
-        refPointCombo.addItem(
-            this.referencePoints[i][1] + " (" + shortcutLabel + ")",
-            this.referencePoints[i][2]
-        );
-        if (isNull(this.shortcuts[i])) {
-            this.shortcuts[i] = new QShortcut(new QKeySequence(shortcut), refPointCombo, 0, 0, Qt.WindowShortcut);
-            this.shortcuts[i].activated.connect(new KeyReactor(i), "activated");
-        }
-    }
-
-    if (isNull(this.referencePointIndex) ||
-        this.referencePointIndex<0 ||
-        this.referencePointIndex>this.referencePoints.length-1) {
-
-        this.referencePointIndex = 4;
-    }
-
-    refPointCombo.blockSignals(false);
-    refPointCombo.currentIndex = this.referencePointIndex;
+    OptionsToolBar.initReferencePointCombo9(optionsToolBar, this);
 };
 
 DrawBasedOnRectangleSize.prototype.pickCoordinate = function(event, preview) {
@@ -305,15 +267,15 @@ DrawBasedOnRectangleSize.prototype.updateOkButton = function() {
 
 
 
-/**
- * Reacts to an assigned shortcut for the given index of the reference point combo box.
- */
-function KeyReactor(i) {
-    this.i = i;
-}
+///**
+// * Reacts to an assigned shortcut for the given index of the reference point combo box.
+// */
+//function KeyReactor(i) {
+//    this.i = i;
+//}
 
-KeyReactor.prototype.activated = function() {
-    var optionsToolBar = EAction.getOptionsToolBar();
-    var refPointCombo = optionsToolBar.findChild("ReferencePoint");
-    refPointCombo.currentIndex = this.i;
-};
+//KeyReactor.prototype.activated = function() {
+//    var optionsToolBar = EAction.getOptionsToolBar();
+//    var refPointCombo = optionsToolBar.findChild("ReferencePoint");
+//    refPointCombo.currentIndex = this.i;
+//};
